#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <array>
#include <chrono>
#include <unordered_set>
#include <queue>
#include <deque>
#include <cmath>
#include <cassert>

using namespace std;

#pragma GCC optimize("unroll-loops")
#pragma GCC target("avx,avx2,sse,sse2,sse3,sse4.1,sse4.2,tune=native")

#define int long long

const int k = 475;
const double eps = 1e-7;
const int inf = 1e18;

struct Fenwick {
    vector<int> f;
    
    Fenwick() {}
    Fenwick(int n) {
        f.assign(n, 0);
    }
    
    int get(int i) {
        int res = 0;
        while (i >= 0) {
            res += f[i];
            i = (i & (i + 1)) - 1;
        }
        return res;
    }
    
    void upd(int i, int n, int val) {
        while (i < n) {
            f[i] += val;
            i = i | (i + 1);
        }
    }
    
    int get(int l, int r) {
        if (l == 0) {
            return get(r);
        }
        return get(r) - get(l - 1);
    }
};

struct Treap {
    struct Node {
        Node* left = nullptr;
        Node* right = nullptr;
        int size = 0;
        int x, y;
        
        Node() {}
        
        Node(int x): x(x) {
            y = rand();
        }
    };
    
    int sz(Node* x) {
        if (!x) {
            return 0;
        }
        return x->size;
    }
    
    void upd(Node* x) {
        if (!x) {
            return;
        }
        x->size = sz(x->left) + sz(x->right) + 1;
    }
    
    Node* merge(Node* left, Node* right) {
        if (!left) {
            return right;
        }
        if (!right) {
            return left;
        }
        if (left->y > right->y) {
            left->right = merge(left->right, right);
            upd(left);
            return left;
        } else {
            right->left = merge(left, right->left);
            upd(right);
            return right;
        }
    }
    
    pair<Node*, Node*> split(Node* p, int k) {  //  split by x
        if (!p) return { nullptr, nullptr };
        if (p->x <= k) {
            pair<Node*, Node*> q = split(p->right, k);
            p->right = q.first;
            upd(p);
            return { p, q.second };
        } else {
            pair<Node*, Node*> q = split(p->left, k);
            p->left = q.second;
            upd(p);
            return { q.first, p };
        }
    }
    
    Node* root = nullptr;
    
    void add(int x) {
        pair<Node*, Node*> q = split(root, x);
        Node* t = new Node(x);
        root = merge(q.first, merge(t, q.second));
    }
    
    void erase(int x) {
        pair<Node*, Node*> q = split(root, x);
        pair<Node*, Node*> q1 = split(q.first, x - 1);
        root = merge(q1.first, q.second);
    }
    
    bool has(int x) {
        pair<Node*, Node*> q = split(root, x);
        pair<Node*, Node*> q1 = split(q.first, x - 1);
        bool ok = q1.second;
        root = merge(q1.first, merge(q1.second, q.second));
        return ok;
    }
};

struct SegTreeMaxSegUpd {
    vector<int> tree;
    vector<int> add;
    
    void init(int n) {
        tree.assign(n * 4, 0);
        add.assign(n * 4, 0);
    }
    
    void build(int i, int l, int r, vector<int> &a) {
        if (l + 1 == r) {
            tree[i] = a[l];
            return;
        }
        int m = (l + r) / 2;
        build(i * 2 + 1, l, m, a);
        build(i * 2 + 2, m, r, a);
        tree[i] = max(tree[i * 2 + 1], tree[i * 2 + 2]);
    }
    
    inline void push(int i) {
        add[i * 2 + 1] += add[i];
        add[i * 2 + 2] += add[i];
        add[i] = 0;
    }
    
    void upd(int i, int l, int r, int ql, int qr, int val) {
        if (qr <= l || r <= ql) {
            return;
        }
        if (ql <= l && r <= qr) {
            add[i] += val;
            return;
        }
        int m = (l + r) / 2;
        push(i);
        upd(i * 2 + 1, l, m, ql, qr, val);
        upd(i * 2 + 2, m, r, ql, qr, val);
        tree[i] = max(tree[i * 2 + 1] + add[i * 2 + 1], tree[i * 2 + 2] + add[i * 2 + 2]);
    }
    
    int get(int i, int l, int r, int ql, int qr) {
        if (qr <= l || r <= ql) {
            return -1e9;
        }
        if (ql <= l && r <= qr) {
            return tree[i] + add[i];
        }
        int m = (l + r) / 2;
        push(i);
        int res = max(get(i * 2 + 1, l, m, ql, qr), get(i * 2 + 2, m, r, ql, qr));
        tree[i] = max(tree[i * 2 + 1] + add[i * 2 + 1], tree[i * 2 + 2] + add[i * 2 + 2]);
        return res;
    }
};

vector<int> mult(vector<int> &a, vector<int> &b) {   // multiplies two polynoms (|a| = |b| = 2^k).
    //  ab = (a0 + x^(n/2)a1)(b0 + x^(n/2)b1) = a0b0 + x^(n/2)(a1b0 + a0b1) + x^na1b1
    if (a.size() == 1) {
        return vector<int> (1, a[0] * b[0]);
    }
    int curr = a.size();
    vector<int> a0, a1, b0, b1;
    for (int i = 0; i < curr / 2; ++i) {
        a0.push_back(a[i]);
    }
    for (int i = curr / 2; i < curr; ++i) {
        a1.push_back(a[i]);
    }
    for (int i = 0; i < curr / 2; ++i) {
        b0.push_back(b[i]);
    }
    for (int i = curr / 2; i < curr; ++i) {
        b1.push_back(b[i]);
    }
    vector<int> a0b0 = mult(a0, b0);
    vector<int> a1b1 = mult(a1, b1);
    for (int i = 0; i < curr / 2; ++i) {
        a0[i] += a1[i];
        b0[i] += b1[i];
    }
    vector<int> mem = mult(a0, b0);
    for (int i = 0; i < curr; ++i) {
        mem[i] -= a0b0[i] + a1b1[i];
    }
    vector<int> ans(curr * 2);
    for (int i = 0; i < curr; ++i) {
        ans[i] = a0b0[i];
        ans[i + curr] = a1b1[i];
    }
    for (int i = 0; i < curr; ++i) {
        ans[i + curr / 2] += mem[i];
    }
    return ans;
}

struct Point {
    int x, y;
    
    Point() {}
    
    Point(int x, int y): x(x), y(y) {}
    
    double dist(Point a) {
        int dx = x - a.x;
        int dy = y - a.y;
        return sqrt(dx * dx + dy * dy);
    }
};

vector<int> dstQ(vector<vector<pair<int, int>>> &g, int v) {
    const int n = g.size();
    vector<int> dist(n, inf);
    priority_queue<pair<int, int>> q;
    q.push({ 0, v });
    dist[v] = 0;
    vector<bool> used(n, false);
    while (!q.empty()) {
        auto [ww, v] = q.top();
        q.pop();
        if (used[v]) {
            continue;
        }
        used[v] = true;
        for (auto [u, w] : g[v]) {
            if (dist[u] > dist[v] + w) {
                dist[u] = dist[v] + w;
                q.push({ -dist[u], u });
            }
        }
    }
    return dist;
}

vector<int> dstSet(vector<vector<pair<int, int>>> &g, int v) {
    const int n = g.size();
    vector<int> dist(n, inf);
    set<pair<int, int>> q;
    q.insert({ 0, v });
    dist[v] = 0;
    while (!q.empty()) {
        int v = q.begin()->second;
        q.erase(q.begin());
        for (auto [u, w] : g[v]) {
            if (dist[u] > dist[v] + w) {
                q.erase({ dist[u], u });
                dist[u] = dist[v] + w;
                q.insert({ dist[u], u });
            }
        }
    }
    return dist;
}

/*
match -- правая доля (с кем матчим из левой)
bool khun(int v, vector<vector<int>> &g) {
    used[v] = true;
    for (int u : g[v]) {
        if (!used[u]) {
            if (match[u] == -1 || dfs(match[u]) {
                match[u] = v;
                return true;
            }
        }
    }
    return false;
}
*/

int binPow(int x, int n, int mod) {
    int res = 1;
    while (n) {
        if (n & 1) {
            res *= x;
            res %= mod;
        }
        x *= x;
        x %= mod;
        n /= 2;
    }
    return res;
}

int gcd(int a, int b) {
    if (!b) {
        return a;
    }
    return gcd(b, a % b);
}

int rev(int a, int m) {  //  find x | (x * a) % m = 1. a, m <= 1e9
    if (a == 1) {
        return 1;
    }
    return (1 - rev(m % a, a) * m) / a + m;
}

void solve() {
    int n, m;
    cin >> n >> m;
    vector<vector<int>> free(m);
    vector<int> cnt(n, 0);
    vector<vector<int>> days(n);
    for (int i = 0; i < m; ++i) {
        int k;
        cin >> k;
        for (int j = 0; j < k; ++j) {
            int x;
            cin >> x;
            --x;
            ++cnt[x];
            days[x].push_back(i);
            free[i].push_back(x);
        }
    }
    vector<int> used(m, -1);
    for (int i = 0; i < n; ++i) {
        if (cnt[i] <= (m + 1) / 2) {
            for (int j : days[i]) {
                used[j] = i;
            }
        }
    }
    vector<int> left;
    for (int i = 0; i < m; ++i) {
        if (used[i] == -1) {
            left.push_back(i);
        }
    }
    vector<int> can(m, 0);
    for (int i = 0; i < n; ++i) {
        for (int j : days[i]) {
            ++can[j];
        }
    }
    set<pair<int, int>> ps;
    for (int i = 0; i < m; ++i) {
        if (used[i] == -1) {
            ps.insert({ can[i], i });
        }
    }
    vector<int> lft(n, (m + 1) / 2);
    while (!ps.empty()) {
        int v = ps.begin()->second;
        ps.erase(ps.begin());
        int id = -1;
        for (int i : free[v]) {
            if (lft[i] > 0 && id == -1) {
                id = i;
            } else if (id != -1 && lft[i] > lft[id]) {
                id = i;
            }
        }
        if (id == -1) {
            cout << "NO\n";
            return;
        }
        --lft[id];
        used[v] = id;
    }
    cout << "YES\n";
    for (int i : used) {
        cout << i + 1 << ' ';
    }
    cout << '\n';
}

int32_t main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    auto start = chrono::high_resolution_clock().now();
    
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
    
    auto end = chrono::high_resolution_clock().now();
    cerr << "Execution time: " << chrono::duration_cast<chrono::milliseconds>(end - start).count() << "ms";
}
