#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <set>
#include <map>
#include <queue>
#include <cmath>

using namespace std;

long long norm(long long a, long long m)
{
	return (a % m + m) % m;
}

long long add(long long a, long long b, long long m)
{
	return norm(norm(a, m) + norm(b, m), m);
}

long long sub(long long a, long long b, long long m)
{
	return norm(norm(a, m) - norm(b, m), m);
}

long long mul(long long a, long long b, long long m)
{
	return norm(norm(a, m) * norm(b, m), m);
}

struct segment_tree
{
	int n;
	vector <long long> mas;
	vector <long long> res;
	vector <long long> promise;

	segment_tree(vector <long long>& _mas)
	{
		n = _mas.size();
		mas = _mas;
		res.resize(4 * n);
		promise.resize(4 * n, 0);

		build(0, 0, n);
	}

	void build(int id, int l, int r)
	{
		if (r - l == 1)
		{
			res[id] = mas[l];
			return;
		}

		int m = (l + r) / 2;
		build(id * 2 + 1, l, m);
		build(id * 2 + 2, m, r);
		res[id] = res[id * 2 + 1] + res[id * 2 + 2];
	}

	void push(int id, int l, int r)
	{
		if (promise[id] == 0) return;
		res[id] += promise[id];
		if (r - l > 1)
		{
			promise[id * 2 + 1] += promise[id];
			promise[id * 2 + 2] += promise[id];
		}
		promise[id] = 0;
	}

	void upd(int id, int l, int r, int lq, int rq, long long delta)
	{
		push(id, l, r);
		if (lq <= l && r <= rq)
		{
			promise[id] += delta;
			push(id, l, r);
			return;
		}
		if (r <= lq || rq <= l) return;

		int m = (l + r) / 2;
		upd(id * 2 + 1, l, m, lq, rq, delta);
		upd(id * 2 + 2, m, r, lq, rq, delta);
		res[id] = res[id * 2 + 1] + res[id * 2 + 2];
	}

	long long get(int id, int l, int r, int lq, int rq)
	{
		push(id, l, r);
		if (lq <= l && r <= rq) return res[id];
		if (r <= lq || rq <= l) return 0;

		int m = (l + r) / 2;
		long long left = get(id * 2 + 1, l, m, lq, rq);
		long long right = get(id * 2 + 2, m, r, lq, rq);
		return left + right;
	}
};

struct hsh
{
	int n;
	long long p, m;
	string s;
	vector <long long> p_deg;
	vector <long long> pref;

	hsh(string& _s, long long _p, long long _m)
	{
		n = _s.size();
		p = _p;
		m = _m;
		s = _s;
		p_deg.resize(n + 1);
		pref.resize(n + 1);

		p_deg[0] = 1;
		for (int i = 1; i < n + 1; ++i)
		{
			p_deg[i] = mul(p_deg[i - 1], p, m);
		}
		pref[0] = 0;
		for (int i = 1; i < n + 1; ++i)
		{
			pref[i] = add(mul(pref[i - 1], p, m), (long long)s[i - 1], m);
		}
	}

	long long substr(int l, int len)
	{
		return sub(pref[l + len], mul(pref[l], p_deg[len], m), m);
	}

	bool are_equal(int l1, int len1, int l2, int len2)
	{
		return substr(l1, len1) == substr(l2, len2);
	}
};

vector <long long> compressed_coords;

void compress(vector <long long>& mas)
{
	compressed_coords = mas;
	compressed_coords.erase(unique(compressed_coords.begin(), compressed_coords.end()), compressed_coords.end());
}

long long get_compressed_coord(long long val)
{
	return lower_bound(compressed_coords.begin(), compressed_coords.end(), val) - compressed_coords.begin();
}

int main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	cout.setf(ios::fixed);
	cout.precision(11);

	int t;
	cin >> t;
	for (int z = 0; z < t; ++z)
	{
		int n, m;
		cin >> n >> m;
		vector <vector <int>> days(m);
		vector <vector <int>> friends(n);
		vector <vector <int>> friends_ones_cnt(n);
		int big = -1;
		bool exist = true;
		for (int i = 0; i < m; ++i)
		{
			int k;
			cin >> k;
			for (int j = 0; j < k; ++j)
			{
				int a;
				cin >> a;
				--a;
				days[i].push_back(a);
				if (k == 1)
				{
					friends_ones_cnt[days[i][0]].push_back(i);
					if (friends_ones_cnt[days[i][0]].size() > m / 2 + m % 2) exist = false;
				}
				else
				{
					friends[a].push_back(i);
				}
				if (friends_ones_cnt[a].size() + friends[a].size() >= m / 2 + m % 2) big = a;
			}
		}
		if (exist == false)
		{
			cout << "NO\n";
			continue;
		}
		vector <int> ans(m, -1);
		if (big != -1)
		{
			for (int i = 0; i < friends_ones_cnt[big].size(); ++i)
			{
				ans[friends_ones_cnt[big][i]] = big;
			}
			for (int i = 0; i < m / 2 + m % 2 - friends_ones_cnt[big].size(); ++i)
			{
				ans[friends[big][i]] = big;
			}
		}
		cout << "YES\n";
		for (int i = 0; i < m; ++i)
		{
			if (ans[i] != -1) cout << ans[i] + 1 << " ";
			else
			{
				if (days[i][0] != big) cout << days[i][0] + 1 << " ";
				else cout << days[i][1] + 1 << " ";
			}
		}
		cout << "\n";
	}
	return 0;
}