#include <iostream>
#include <cmath>
#include <chrono>
#include <vector>
#include <bitset>
#include <string>
#include <functional>
#include <iomanip>
#include <array>
#include <stack>

using namespace std;

template<typename T>
string to_string(vector<T> &a) {
    string res = "{";
    bool first = 1;
    for (auto &i : a) {
        if (!first) {
            res += ", ";
        }
        first = 0;
        res += to_string(i);
    }
    res += "}";
    return res;
}

void debug_out() {
    cerr << endl;
}

template<typename Head, typename... Tail>
void debug_out(Head H, Tail... T) {
    cerr << ' ' << to_string(H); 
    debug_out(T...);
}

typedef long long ll;
typedef long double ld;

// #define int long long
#define x first
#define y second
#define all(a) a.begin(), a.end()
#define sz(a) (int) a.size()
#define pb push_back

#ifdef LOCAL
#define debug(...) cerr << "[" << #__VA_ARGS__ << "]:", debug_out(__VA_ARGS__)
#else
#define debug(...) 22888
#endif

const int N = 3e5 + 5;
const int INF = 1e9 + 7;
const ld EPS = 1e-12;

int gcd(int a, int b) {
    if (a == 0) return b;
    if (b == 0) return a;
    return gcd(b % a, a);
}

struct segtree {

    struct node {
        int pref, suf, idxpref, idxsuf, idx_min;
    };

    int s;
    vector<node> tree;

    segtree(int n) {
        s = 1;
        while (s < n) {
            s *= 2;
        }
        tree.assign(2 * s + 1, {0, 0, INF, INF, INF});
    }

    node combine(node a, node b) {
        if (a.pref == 0) return b;
        if (b.pref == 0) return a;
        return {
            a.pref,
            b.suf,
            a.idxpref,
            b.idxsuf,
            min({b.idx_min, a.idx_min, (gcd(a.suf, b.pref) == 1 ? b.idxpref : INF)})
        };
    }

    // void push(int x, int lx, int rx) {
    //     if (lx + 1 == rx || tree[x].p == 0) return;
    //     int p = tree[x].p;
    //     tree[2 * x + 1].p += p;
    //     tree[2 * x + 2].p += p;
    //     tree[2 * x + 1].v += p;
    //     tree[2 * x + 2].v += p;
    //     tree[x].p = 0;
    // }

    void build(vector<int> &a, int x, int lx, int rx) {
        if (lx + 1 == rx) {
            if (lx < sz(a)) {
                tree[x] = {a[lx], a[lx], lx, lx, INF};
            }
            return;
        }
        int m = (lx + rx) / 2;
        build(a, 2 * x + 1, lx, m);
        build(a, 2 * x + 2, m, rx);
        tree[x] = combine(tree[2 * x + 1], tree[2 * x + 2]);
    }

    void set(int i, int x, int lx, int rx) {
        if (lx + 1 == rx) {
            // debug(1, lx, rx);
            tree[x] = {0, 0, 0, 0, INF};
            return;
        } 
        int m = (lx + rx) / 2;
        if (i < m) {
            set(i, 2 * x + 1, lx, m);
        } else {
            set(i, 2 * x + 2, m, rx);
        }
        tree[x] = combine(tree[2 * x + 1], tree[2 * x + 2]);
        // debug(lx, rx, tree[x].pref, tree[x].suf);
    }

    node get(int l, int r, int x, int lx, int rx) {
        if (lx >= r || rx <= l) {
            return {0, 0, INF, INF, INF};
        }
        if (lx >= l && rx <= r) {
            return tree[x];
        }
        int m = (lx + rx) / 2;
        return combine(get(l, r, 2 * x + 1, lx, m), get(l, r, 2 * x + 2, m, rx));
    }

};

void solve() {
    int n;
    cin >> n;
    vector<int> a(n);
    for (auto &i : a) {
        cin >> i;
    }
    segtree sg(n * 2);
    sg.build(a, 0, 0, sg.s);
    vector<int> res;
    int i = 0;
    while (true) {
        // debug(i);
        auto [pp, ss, ipre, isuf, idx] = sg.get(i, n, 0, 0, sg.s);
        // debug(idx);
        if (idx == INF) {
            auto [pref, suf, idxpref, idxsuf, mn] = sg.get(0, n, 0, 0, sg.s);
            // debug(mn, pref, ss);
            if (gcd(pref, ss) == 1 && ss) {
                mn = idxpref;
            }
            if (mn == INF) {
                break;
            } else {
                sg.set(mn, 0, 0, sg.s);
                res.pb(mn + 1);
                i = mn;
            }
        } else {
            sg.set(idx, 0, 0, sg.s);
            i = idx;
            res.pb(idx + 1);
        }
        i = (i + 1) % n;
        if (sg.get(i, n, 0, 0, sg.s).idxsuf == INF) i = 0;
    }
    cout << sz(res) << ' ';
    for (auto &i : res) {
        cout << i << ' ';
    }
    cout << '\n';
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);

    int tests = 1;
    cin >> tests;

    while (tests-- > 0) {
        solve();
    }
}