#include <iostream>
#include <random>
#include <chrono>
#include <string>
#include <algorithm>

using namespace std;

typedef pair <int, int> pii;

mt19937 rnd(time(0));

struct node {
  int x, y;
  int sz;
  int id;
  int fl; // 1, если gcd(a[i], a[i + 1]) == 1
  int mx; // максимум по fl в поддереве
  node *l, *r;
  node(int _x, int _fl, int _id) {
    x = _x;
    sz = 1;
    fl = mx = _fl;
    id = _id;
    y = rnd();
    l = r = nullptr;
  }
  static int get_sz(node* p) {
    if (!p)
      return 0;
    return p->sz;
  }
  static int get_mx(node* p) {
    if (!p)
      return 0;
    return p->mx;
  }
  static void upd(node* p) {
    if (!p)
      return;
    p->sz = 1 + get_sz(p->l) + get_sz(p->r);
    p->mx = max({p->fl, get_mx(p->l), get_mx(p->r)});
  }
  static node* merge(node* l, node* r) {
    if (!l)
      return r;
    if (!r)
      return l;
    if (l->y > r->y) {
      l->r = merge(l->r, r);
      upd(l);
      return l;
    } else {
      r->l = merge(l, r->l);
      upd(r);
      return r;
    }
  }
  static pair <node*, node*> split(int x, node* p) {
    if (!p)
      return {};
    if (x <= get_sz(p->l) + 1) {
      pair <node*, node*> tmp = split(x, p->l);
      p->l = tmp.second;
      upd(p);
      return {tmp.first, p};
    } else {
      pair <node*, node*> tmp = split(x - get_sz(p->l) - 1, p->r);
      p->r = tmp.first;
      upd(p);
      return {p, tmp.second};
    }
  }
  static void erase(int pos, node* &p) {
    pair <node*, node*> tmp1 = split(pos, p);
    pair <node*, node*> tmp2 = split(2, tmp1.second);
    p = merge(tmp1.first, tmp2.second);
  }
  static void insert(int pos, int x, int fl, int id, node* &p) {
    node* n = new node(x, fl, id);
    pair <node*, node*> tmp = split(pos, p);
    p = merge(tmp.first, merge(n, tmp.second));
  }
  static void shift(int pos, node* &p) {
    pair <node*, node*> tmp = split(pos + 1, p);
    p = merge(tmp.second, tmp.first);
  }
  static pii first_one(node* p) {
    if (!p)
      return {-1, -1};
    if (p->mx == 0)
      return {-1, -1};
    pii res = first_one(p->l);
    if (res != make_pair(-1, -1))
      return res;
    if (p->fl)
      return {get_sz(p->l) + 1, p->id};
    res = first_one(p->r);
    return make_pair(res.first + get_sz(p->l) + 1, res.second);
  }
  static pii get_val(int pos, node* p) {
    if (pos < get_sz(p->l) + 1)
      return get_val(pos, p->l);
    if (pos == get_sz(p->l) + 1)
      return {p->x, p->id};
    return get_val(pos - get_sz(p->l) - 1, p->r);
  }
  static void write(node* p) {
    if (!p)
      return;
    write(p->l);
    cout << p->x << ' ';
    write(p->r);
  }
};

int main() {
  ios::sync_with_stdio(false);
  cin.tie(0);
  int t;
  cin >> t;
  while (t--) {
    int n;
    cin >> n;
    vector <int> a(n);
    for (int i = 0; i < n; i++)
      cin >> a[i];
    node* T = nullptr;
    for (int i = 0; i < n; i++) {
      int g = __gcd(a[i], a[(i + 1) % n]);
      int fl = (g == 1 ? 1 : 0);
      node::insert(i + 1, a[i], fl, i + 1, T);
    }
    vector <int> ans;
    while (true) {
      pii res = node::first_one(T);
      int pos = res.first;
      if (pos == -1)
        break;
      {
        pii tmp = node::get_val(pos % n + 1, T);
        ans.push_back(tmp.second);
        node::erase(pos % n + 1, T);
        n--;
        if (!n)
          break;
      }
      pii x = node::get_val((pos > n ? pos - 1 : pos), T);
      pii y = node::get_val((pos > n ? pos - 1 : pos) % n + 1, T);
      int g = __gcd(x.first, y.first);
      int fl = (g == 1 ? 1 : 0);
      node::erase((pos > n ? pos - 1 : pos), T);
      node::insert((pos > n ? pos - 1 : pos), x.first, fl, x.second, T);
      node::shift(pos, T);
    }
    cout << ans.size() << ' ';
    for (int x : ans)
      cout << x << ' ';
    cout << '\n';
  }
  return 0;
}

/*
1
4
1 2 4 1
*/
