#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <cmath>
#include <iomanip>
#include <algorithm>
#include <utility>
#include <stack>
#include <queue>
#include <deque>
using namespace std;
#define int long long

vector <int> divisors(int n) {
    vector <int> ans;
    for (int i = 1; i * i <= n; ++i) {
        if (n % i == 0) {
            ans.push_back(i);
            ans.push_back(n / i);
        }
    }
    sort(ans.rbegin(), ans.rend());
    return ans;
}

int gcd(int a, int b) {
    return b == 0 ? a : gcd(b, a % b);
}

class SegTree {
    int n;
    vector <int> t;
public:
    SegTree(vector <int> a) {
        this->n = a.size();
        t.resize(2 * n);
        for (int i = 0; i < n; ++i) {
            t[i + n] = a[i];
        }
        for (int i = n - 1; i > 0; --i) {
            t[i] = gcd(t[2 * i], t[2 * i + 1]);
        }
    }
    void update(int pos, int val) {
        t[pos + n] = val;
        for (int i = (pos + n) / 2; i > 0; i /= 2) {
            t[i] = gcd(t[2 * i], t[2 * i + 1]);
        }
    }

    int query(int l, int r) {
        l += n, r += n;
        int ans = 0;
        while (l <= r) {
            if (l % 2 == 1) {
                ans = gcd(ans, t[l++]);
            }
            if (r % 2 == 0) {
                ans = gcd(ans, t[r--]);
            }
            l /= 2, r /= 2;
        }
        return ans;
    }
};

class SegTreeSum {
    int n;
    vector <int> t;
public:
    SegTreeSum(int n) {
        this->n = n;
        t.resize(2 * n);
    }
    void update(int pos, int val) {
        t[pos + n] = val;
        for (int i = (pos + n) / 2; i > 0; i /= 2) {
            t[i] = t[2 * i] + t[2 * i + 1];
        }
    }

    int query(int l, int r) {
        l += n, r += n;
        int ans = 0;
        while (l <= r) {
            if (l % 2 == 1) {
                ans += t[l++];
            }
            if (r % 2 == 0) {
                ans += t[r--];
            }
            l /= 2, r /= 2;
        }
        return ans;
    }
};

void solve() {
    int n;
    cin >> n;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }
    set <int> bad;
    vector <int> removed(n);
    vector <int> ans;
    int left = n;
    for (int i = 0; i < n; ++i) {
        if (gcd(a[i], a[(i - 1 + n) % n]) == 1) {
            bad.insert(i);
        }
    }
    auto check = [&](int pos1, int pos2) {
        bool ok = false;
        for (int i = pos1; i != pos2; i = (i + 1) % n) {
            if (removed[i] == 0) {
                ok = true;
            }
        }
        return ok;
    };
    int skip = 0;
    set <int> vac1, vac2;
    for (int i = 0; i < n; ++i) {
        vac1.insert(i);
        vac2.insert(-i);
    }
    while(true) {
        bool nevdel = false;
        int last = 0;
        while (bad.lower_bound(last) != bad.end()) {
            int i = *(bad.lower_bound(last));
            last = i + 1;
            if (removed[i] == 0 && i != skip) {
                removed[i] = true;
                vac1.erase(i);
                vac2.erase(-i);
                nevdel = true;
                ans.push_back(i);
                --left;
                if (left == 0) break;
//                int j = i;
//                while (removed[j] == 1) j = (j + 1) % n;
                int j;
                if (vac1.upper_bound(i) != vac1.end()) j = *(vac1.upper_bound(i));
                else j = *(vac1.begin());
//                int j2 = i;
//                while (removed[j2] == 1) {
//                    j2 = (j2 - 1 + n) % n;
//                }
                int j2;
                if (vac2.upper_bound(-i) != vac2.end()) j2 = -1 * *(vac2.upper_bound(-i));
                else j2 = -1 * *(vac2.begin());
                if (gcd(a[j], a[j2]) == 1 && removed[j] == 0) {
                    bad.insert(j);
                    skip = j;
                } else {
                    bad.erase(j);
                }
            }
        }
        if (nevdel == false && removed[skip] == 0 && bad.find(skip) != bad.end()) {
            int i = skip;
            removed[i] = true;
            vac1.erase(i);
            vac2.erase(-i);
            nevdel = true;
            ans.push_back(i);
            --left;
            if (left == 0) break;
//                int j = i;
//                while (removed[j] == 1) j = (j + 1) % n;
            int j;
            if (vac1.upper_bound(i) != vac1.end()) j = *(vac1.upper_bound(i));
            else j = *(vac1.begin());
//                int j2 = i;
//                while (removed[j2] == 1) {
//                    j2 = (j2 - 1 + n) % n;
//                }
            int j2;
            if (vac2.upper_bound(-i) != vac2.end()) j2 = -1 * *(vac2.upper_bound(-i));
            else j2 = -1 * *(vac2.begin());
            if (gcd(a[j], a[j2]) == 1 && removed[j] == 0) {
                bad.insert(j);
                skip = j;
            } else {
                bad.erase(j);
            }
        }
        set <int> st2;
        for (int i : bad) {
            if (removed[i] == 0) {
                st2.insert(i);
            }
        }
        bad = st2;
        if (nevdel == false) break;
    }

    cout << ans.size() << " ";
    for (int i : ans) {
        cout << (i) % n + 1 << " ";
    }
}

int32_t main() {
#ifdef _LOCAL
    freopen("input.txt", "r", stdin);
#endif
    int test = 1;
    cin >> test;
    while (test--) {
        solve();
        cout << "\n";
    }
}