#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <array>
#include <chrono>
#include <unordered_set>
#include <queue>
#include <deque>
#include <cmath>
#include <cassert>

using namespace std;

#pragma GCC optimize("unroll-loops")
#pragma GCC target("avx,avx2,sse,sse2,sse3,sse4.1,sse4.2,tune=native")

#define int long long

const int k = 475;
const double eps = 1e-7;
const int inf = 1e18;

struct SegTree {
    vector<int> tree;
    
    void init(int n) {
        tree.assign(n * 4, -inf);
    }
    
    void upd(int i, int l, int r, int qi, int val) {
        if (r < qi || qi < l) {
            return;
        }
        if (l + 1 == r) {
            tree[i] = val;
            return;
        }
        int m = (l + r) / 2;
        upd(i * 2 + 1, l, m, qi, val);
        upd(i * 2 + 2, m, r, qi, val);
        tree[i] = max(tree[i * 2 + 1], tree[i * 2 + 2]);
    }
    
    int get(int i, int l, int r, int ql, int qr) {
        if (qr <= l || r <= ql) {
            return -inf;
        }
        if (ql <= l && r <= qr) {
            return tree[i];
        }
        int m = (l + r) / 2;
        return max(get(i * 2 + 1, l, m, ql, qr), get(i * 2 + 2, m, r, ql, qr));
    }
};

struct SparseTable {
    int st[20][300000];
    int logg[300001];
    
    void build(vector<int> &a) {
        const int n = a.size();
        for (int i = 0; i < n; ++i) {
            st[0][i] = a[i];
        }
        for (int i = 1; i < 20; ++i) {
            for (int j = 0; j + (1 << i) - 1 < n; ++j) {
                st[i][j] = min(st[i - 1][j], st[i - 1][j + (1 << (i - 1))]);
            }
        }
        logg[1] = 0;
        for (int i = 2; i <= 300000; ++i) {
            logg[i] = logg[i / 2] + 1;
        }
    }
    
    int get(int l, int r) {
        l = max(l, 0ll);
        int len = r - l + 1;
        return min(st[logg[len]][l], st[logg[len]][r - (1 << logg[len]) + 1]);
    }
};

SparseTable sp;

void solve() {
    int n;
    cin >> n;
    vector<int> h(n);
    vector<int> b(n);
    for (int& i : h) {
        cin >> i;
    }
    for (int& i : b) {
        cin >> i;
    }
    sp.build(h);
    SegTree st;
    SegTree st1;
    st.init(n + 1);
    st1.init(n + 1);
    vector<int> dp(n + 1, 0);
    vector<int> stt;
    st1.upd(0, 0, n + 1, 0, 0);
    for (int i = 1; i <= n; ++i) {
        while (!stt.empty() && h[stt.back() - 1] > h[i - 1]) {
            st.upd(0, 0, n, stt.back(), -inf);
            stt.pop_back();
        }
        int l = -1, r = i;
        while (l + 1 < r) {
            int m = (l + r) / 2;
            if (sp.get(m - 1, i - 1) != h[i - 1]) {
                l = m;
            } else {
                r = m;
            }
        }
        int left = r;
        dp[i] = max({ st1.get(0, 0, n + 1, left, i) + b[i - 1], st.get(0, 0, n + 1, 0, left), dp[i - 1] + b[i - 1] });
        st.upd(0, 0, n, i, dp[i]);
        st1.upd(0, 0, n, i, dp[i - 1]);
        stt.push_back(i);
    }
    cout << dp.back() << '\n';
}

int32_t main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    auto start = chrono::high_resolution_clock().now();
    
    int t;
    t = 1;
    while (t--) {
        solve();
    }
    
    auto end = chrono::high_resolution_clock().now();
    cerr << "Execution time: " << chrono::duration_cast<chrono::milliseconds>(end - start).count() << "ms";
}
